Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(107)

Unified Diff: tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py

Issue 2062963003: Add a flag to disable server experiments in DRP (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: kundaji comments Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/data_reduction_proxy/core/common/data_reduction_proxy_switches.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
diff --git a/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py b/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
index c9ce789fca3fadba6e176c5ce3d8f3d9677f2d33..cf6e56db52fe8d9c7e176b1f0f8d855452c0fea2 100644
--- a/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
+++ b/tools/chrome_proxy/integration_tests/chrome_proxy_measurements.py
@@ -275,6 +275,9 @@ class ChromeProxyLoFi(ChromeProxyValidation):
def CustomizeBrowserOptions(self, options):
super(ChromeProxyLoFi, self).CustomizeBrowserOptions(options)
options.AppendExtraBrowserArgs('--data-reduction-proxy-lo-fi=always-on')
+ # Disable server experiments such as tamper detection.
+ options.AppendExtraBrowserArgs(
+ '--data-reduction-proxy-server-experiments-disabled')
def AddResults(self, tab, results):
self._metrics.AddResultsForLoFi(tab, results)
@@ -303,14 +306,20 @@ class ChromeProxyCacheLoFiDisabled(ChromeProxyValidation):
def WillStartBrowser(self, platform):
super(ChromeProxyCacheLoFiDisabled, self).WillStartBrowser(platform)
if not self._page:
# First page load, enable LoFi and chrome proxy.
self.options.AppendExtraBrowserArgs(
'--data-reduction-proxy-lo-fi=always-on')
+ self.options.AppendExtraBrowserArgs(
+ '--data-reduction-proxy-server-experiments-disabled')
self._is_lo_fi_enabled = True
else:
# Second page load, disable LoFi. Chrome proxy is still enabled.
self.options.browser_options.extra_browser_args.discard(
'--data-reduction-proxy-lo-fi=always-on')
+ self.options.AppendExtraBrowserArgs(
+ '--data-reduction-proxy-server-experiments-disabled')
self._is_lo_fi_enabled = False
def WillNavigateToPage(self, page, tab):
@@ -349,9 +358,12 @@ class ChromeProxyCacheProxyDisabled(ChromeProxyValidation):
def WillStartBrowser(self, platform):
super(ChromeProxyCacheProxyDisabled, self).WillStartBrowser(platform)
if not self._page:
# First page load, enable LoFi and chrome proxy.
self.options.AppendExtraBrowserArgs(
'--data-reduction-proxy-lo-fi=always-on')
+ self.options.AppendExtraBrowserArgs(
+ '--data-reduction-proxy-server-experiments-disabled')
else:
# Second page load, disable chrome proxy. LoFi is still enabled.
self.DisableChromeProxy()
@@ -303,14 +306,20 @@ class ChromeProxyCacheLoFiDisabled(ChromeProxyValidation):
super(ChromeProxyCacheLoFiDisabled, self).WillStartBrowser(platform)
if not self._page:
- # First page load, enable LoFi and chrome proxy.
+ # First page load, enable LoFi and chrome proxy. Disable server
+ # experiments such as tamper detection.
self.options.AppendExtraBrowserArgs(
'--data-reduction-proxy-lo-fi=always-on')
@@ -303,14 +306,20 @@ class ChromeProxyCacheLoFiDisabled(ChromeProxyValidation):
self._is_lo_fi_enabled = True
else:
- # Second page load, disable LoFi. Chrome proxy is still enabled.
+ # Second page load, disable LoFi. Chrome proxy is still enabled. Disable
+ # server experiments such as tamper detection.
self.options.browser_options.extra_browser_args.discard(
'--data-reduction-proxy-lo-fi=always-on')
@@ -349,9 +358,12 @@ class ChromeProxyCacheProxyDisabled(ChromeProxyValidation):
super(ChromeProxyCacheProxyDisabled, self).WillStartBrowser(platform)
if not self._page:
- # First page load, enable LoFi and chrome proxy.
+ # First page load, enable LoFi and chrome proxy. Disable server
+ # experiments such as tamper detection.
self.options.AppendExtraBrowserArgs(
'--data-reduction-proxy-lo-fi=always-on')
« no previous file with comments | « components/data_reduction_proxy/core/common/data_reduction_proxy_switches.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698